@@ -1,7 +1,6 @@
-/* $Id: gucharmap-chapters.c 1376 2007-12-03 21:42:48Z chpe $ */
 /*
- * Copyright (c) 2004 Noah Levitt
- * Copyright (C) 2007 Christian Persch
+ * Copyright © 2004 Noah Levitt
+ * Copyright © 2007 Christian Persch
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -15,47 +14,54 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
  */
 
-#include "config.h"
-#include "gucharmap-chapters.h"
-#include "gucharmap-marshal.h"
+#include <config.h>
+
 #include <string.h>
 
+#include "gucharmap.h"
+#include "gucharmap-private.h"
+#include "gucharmap-marshal.h"
+
 G_DEFINE_TYPE (GucharmapChaptersModel, gucharmap_chapters_model, GTK_TYPE_LIST_STORE)
 
 static GucharmapCodepointList * 
 default_get_codepoint_list (GucharmapChaptersModel *chapters,
                             GtkTreeIter *iter)
 {
-  return gucharmap_codepoint_list_new (0, UNICHAR_MAX);
+  return gucharmap_block_codepoint_list_new (0, UNICHAR_MAX);
 }
 
 static void
-gucharmap_chapters_model_init (GucharmapChaptersModel *chapters)
+gucharmap_chapters_model_init (GucharmapChaptersModel *model)
 {
+  model->priv = G_TYPE_INSTANCE_GET_PRIVATE (model, GUCHARMAP_TYPE_CHAPTERS_MODEL, GucharmapChaptersModelPrivate);
 }
 
 static void
 gucharmap_chapters_model_finalize (GObject *object)
 {
-  GucharmapChaptersModel *chapters = GUCHARMAP_CHAPTERS_MODEL (object);
+  GucharmapChaptersModel *model = GUCHARMAP_CHAPTERS_MODEL (object);
+  GucharmapChaptersModelPrivate *priv = model->priv;
 
-  if (chapters->book_list)
-    g_object_unref (chapters->book_list);
+  if (priv->book_list)
+    g_object_unref (priv->book_list);
 
   G_OBJECT_CLASS (gucharmap_chapters_model_parent_class)->finalize (object);
 }
 
 static void
-gucharmap_chapters_model_class_init (GucharmapChaptersModelClass *clazz)
+gucharmap_chapters_model_class_init (GucharmapChaptersModelClass *klass)
 {
-  GObjectClass *object_class = G_OBJECT_CLASS (clazz);
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+  g_type_class_add_private (object_class, sizeof (GucharmapChaptersModelPrivate));
 
   object_class->finalize = gucharmap_chapters_model_finalize;
 
-  clazz->get_codepoint_list = default_get_codepoint_list;
+  klass->get_codepoint_list = default_get_codepoint_list;
 }
 
 /**
@@ -74,7 +80,7 @@ GucharmapCodepointList *
 gucharmap_chapters_model_get_codepoint_list (GucharmapChaptersModel *chapters,
                                        GtkTreeIter       *iter)
 {
-  g_return_val_if_fail (IS_GUCHARMAP_CHAPTERS_MODEL (chapters), NULL);
+  g_return_val_if_fail (GUCHARMAP_IS_CHAPTERS_MODEL (chapters), NULL);
 
   return GUCHARMAP_CHAPTERS_MODEL_GET_CLASS (chapters)->get_codepoint_list (chapters, iter);
 }
@@ -83,13 +89,13 @@ gucharmap_chapters_model_get_codepoint_list (GucharmapChaptersModel *chapters,
  * gucharmap_chapters_model_get_codepoint_list:
  * @chapters: a #GucharmapChaptersModel
  *
- * Return value: a #GucharmapCodepointList representing all the characters
- * in all the chapters. It should not be modified or freed.
+ * Return value: a reference to a #GucharmapCodepointList representing all the characters
+ * in all the chapters. It should not be modified, but must be g_object_unref()'d after use.
  **/
-G_CONST_RETURN GucharmapCodepointList * 
+GucharmapCodepointList *
 gucharmap_chapters_model_get_book_codepoint_list (GucharmapChaptersModel *chapters)
 {
-  g_return_val_if_fail (IS_GUCHARMAP_CHAPTERS_MODEL (chapters), NULL);
+  g_return_val_if_fail (GUCHARMAP_IS_CHAPTERS_MODEL (chapters), NULL);
 
   return GUCHARMAP_CHAPTERS_MODEL_GET_CLASS (chapters)->get_book_codepoint_list (chapters);
 }
@@ -104,10 +110,10 @@ gucharmap_chapters_model_get_book_codepoint_list (GucharmapChaptersModel *chapte
  **/
 gboolean
 gucharmap_chapters_model_character_to_iter (GucharmapChaptersModel *chapters,
-                                      gunichar           wc,
-                                      GtkTreeIter       *iter)
+                                            gunichar           wc,
+                                            GtkTreeIter       *iter)
 {
-  g_return_val_if_fail (IS_GUCHARMAP_CHAPTERS_MODEL (chapters), FALSE);
+  g_return_val_if_fail (GUCHARMAP_IS_CHAPTERS_MODEL (chapters), FALSE);
 
   return GUCHARMAP_CHAPTERS_MODEL_GET_CLASS (chapters)->character_to_iter (chapters, wc, iter);
 }
@@ -115,7 +121,7 @@ gucharmap_chapters_model_character_to_iter (GucharmapChaptersModel *chapters,
 const char *
 gucharmap_chapters_model_get_title (GucharmapChaptersModel *chapters)
 {
-  g_return_val_if_fail (IS_GUCHARMAP_CHAPTERS_MODEL (chapters), NULL);
+  g_return_val_if_fail (GUCHARMAP_IS_CHAPTERS_MODEL (chapters), NULL);
 
   return GUCHARMAP_CHAPTERS_MODEL_GET_CLASS (chapters)->title;
 }
@@ -130,7 +136,7 @@ gucharmap_chapters_model_id_to_iter (GucharmapChaptersModel *chapters_model,
   char *str;
   int match;
 
-  g_return_val_if_fail (IS_GUCHARMAP_CHAPTERS_MODEL (model), FALSE);
+  g_return_val_if_fail (GUCHARMAP_IS_CHAPTERS_MODEL (model), FALSE);
 
   if (!id)
     return FALSE;
@@ -139,7 +145,7 @@ gucharmap_chapters_model_id_to_iter (GucharmapChaptersModel *chapters_model,
     return FALSE;
 
   do {
-    gtk_tree_model_get(model, &iter, CHAPTERS_ID_COL, &str, -1);
+    gtk_tree_model_get(model, &iter, GUCHARMAP_CHAPTERS_MODEL_COLUMN_ID, &str, -1);
     match = strcmp (id, str);
     g_free(str);
     if (0 == match) {
