@@ -44,7 +44,7 @@ typedef struct _GucharmapCharmapClass   GucharmapCharmapClass;
 
 struct _GucharmapCharmap
 {
-  GtkHPaned parent;
+  GtkPaned parent;
 
   /*< private >*/
   GucharmapCharmapPrivate *priv;
@@ -52,7 +52,7 @@ struct _GucharmapCharmap
 
 struct _GucharmapCharmapClass
 {
-  GtkHPanedClass parent_class;
+  GtkPanedClass parent_class;
 
   void (* status_message) (GucharmapCharmap *charmap, const gchar *message);
   void (* link_clicked) (GucharmapCharmap *charmap, 
@@ -68,6 +68,12 @@ GType                 gucharmap_charmap_get_type           (void);
 
 GtkWidget *           gucharmap_charmap_new                (void);
 
+#ifndef GUCHARMAP_DISABLE_DEPRECATED
+void           gucharmap_charmap_set_orientation (GucharmapCharmap *charmap,
+                                                  GtkOrientation orientation);
+GtkOrientation gucharmap_charmap_get_orientation (GucharmapCharmap *charmap);
+#endif
+
 void      gucharmap_charmap_set_active_character (GucharmapCharmap *charmap,
                                                   gunichar           uc);
 gunichar  gucharmap_charmap_get_active_character (GucharmapCharmap *charmap);
