@@ -1,6 +1,5 @@
-/* $Id: gucharmap-script-codepoint-list.c 1493 2007-12-12 19:33:26Z chpe $ */
 /*
- * Copyright (c) 2004 Noah Levitt
+ * Copyright © 2004 Noah Levitt
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -17,11 +16,13 @@
  * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 #include <glib.h>
-#include "gucharmap-intl.h"
 #include <string.h>
-#include "gucharmap-script-codepoint-list.h"
+
+#include "gucharmap.h"
+#include "gucharmap-private.h"
+
 #include "unicode-scripts.h"
 
 typedef struct
@@ -32,16 +33,15 @@ typedef struct
 }
 UnicodeRange;
 
-typedef struct _ScriptCodepointListPrivate ScriptCodepointListPrivate;
-
-struct _ScriptCodepointListPrivate 
+struct _GucharmapScriptCodepointListPrivate
 {
   GPtrArray *ranges;
 };
 
-#define GUCHARMAP_SCRIPT_CODEPOINT_LIST_GET_PRIVATE(o) \
-            (G_TYPE_INSTANCE_GET_PRIVATE ((o), gucharmap_script_codepoint_list_get_type (), \
-                                          ScriptCodepointListPrivate))
+static void gucharmap_script_codepoint_list_class_init (GucharmapScriptCodepointListClass *klass);
+static void gucharmap_script_codepoint_list_init       (GucharmapScriptCodepointList      *list);
+
+G_DEFINE_TYPE (GucharmapScriptCodepointList, gucharmap_script_codepoint_list, GUCHARMAP_TYPE_CODEPOINT_LIST)
 
 static gint
 find_script (const gchar *script)
@@ -49,15 +49,15 @@ find_script (const gchar *script)
   gint min, mid, max;
 
   min = 0;
-  max = sizeof (unicode_script_list) / sizeof (gchar *) - 2;  /* it’s NULL-terminated */
+  max = G_N_ELEMENTS (unicode_script_list_offsets) - 1;
 
   while (max >= min) 
     {
       mid = (min + max) / 2;
 
-      if (strcmp (script, unicode_script_list[mid]) > 0)
+      if (strcmp (script, unicode_script_list_strings + unicode_script_list_offsets[mid]) > 0)
         min = mid + 1;
-      else if (strcmp (script, unicode_script_list[mid]) < 0)
+      else if (strcmp (script, unicode_script_list_strings + unicode_script_list_offsets[mid]) < 0)
         max = mid - 1;
       else
         return mid;
@@ -66,7 +66,6 @@ find_script (const gchar *script)
   return -1;
 }
 
-
 /* *ranges should be freed by caller */
 /* adds unlisted characters to the "Common" script */
 static gboolean
@@ -155,7 +154,7 @@ get_chars_for_script (const gchar            *script,
 static void
 ensure_initialized (GucharmapScriptCodepointList *guscl)
 {
-  ScriptCodepointListPrivate *priv = GUCHARMAP_SCRIPT_CODEPOINT_LIST_GET_PRIVATE (guscl);
+  GucharmapScriptCodepointListPrivate *priv = guscl->priv;
   gboolean success;
 
   if (priv->ranges != NULL)
@@ -171,7 +170,7 @@ get_char (GucharmapCodepointList *list,
           gint                    index)
 {
   GucharmapScriptCodepointList *guscl = GUCHARMAP_SCRIPT_CODEPOINT_LIST (list);
-  ScriptCodepointListPrivate *priv = GUCHARMAP_SCRIPT_CODEPOINT_LIST_GET_PRIVATE (guscl);
+  GucharmapScriptCodepointListPrivate *priv = guscl->priv;
   gint min, mid, max;
 
   ensure_initialized (guscl);
@@ -203,7 +202,7 @@ get_index (GucharmapCodepointList *list,
            gunichar                wc)
 {
   GucharmapScriptCodepointList *guscl = GUCHARMAP_SCRIPT_CODEPOINT_LIST (list);
-  ScriptCodepointListPrivate *priv = GUCHARMAP_SCRIPT_CODEPOINT_LIST_GET_PRIVATE (guscl);
+  GucharmapScriptCodepointListPrivate *priv = guscl->priv;
   gint i;
 
   ensure_initialized (guscl);
@@ -222,7 +221,7 @@ static gint
 get_last_index (GucharmapCodepointList *list)
 {
   GucharmapScriptCodepointList *guscl = GUCHARMAP_SCRIPT_CODEPOINT_LIST (list);
-  ScriptCodepointListPrivate *priv = GUCHARMAP_SCRIPT_CODEPOINT_LIST_GET_PRIVATE (guscl);
+  GucharmapScriptCodepointListPrivate *priv = guscl->priv;
   UnicodeRange *last_range;
 
   ensure_initialized (guscl);
@@ -233,13 +232,30 @@ get_last_index (GucharmapCodepointList *list)
 }
 
 static void
-finalize (GObject *object)
+clear_ranges (GPtrArray *ranges)
+{
+  guint i, n;
+
+  n = ranges->len;
+  for (i = 0; i < n; ++i)
+    g_free (g_ptr_array_index (ranges, i));
+
+  g_ptr_array_set_size (ranges, 0);
+}
+
+static void
+gucharmap_script_codepoint_list_finalize (GObject *object)
 {
   GucharmapScriptCodepointList *guscl = GUCHARMAP_SCRIPT_CODEPOINT_LIST (object);
-  ScriptCodepointListPrivate *priv = GUCHARMAP_SCRIPT_CODEPOINT_LIST_GET_PRIVATE (guscl);
+  GucharmapScriptCodepointListPrivate *priv = guscl->priv;
 
   if (priv->ranges)
-    g_ptr_array_free (priv->ranges, TRUE);
+    {
+      clear_ranges (priv->ranges);
+      g_ptr_array_free (priv->ranges, TRUE);
+    }
+
+  G_OBJECT_CLASS (gucharmap_script_codepoint_list_parent_class)->finalize (object);
 }
 
 static void
@@ -248,26 +264,23 @@ gucharmap_script_codepoint_list_class_init (GucharmapScriptCodepointListClass *c
   GucharmapCodepointListClass *codepoint_list_class = GUCHARMAP_CODEPOINT_LIST_CLASS (clazz);
   GObjectClass *gobject_class = G_OBJECT_CLASS (clazz);
 
-  g_type_class_add_private (codepoint_list_class, sizeof (ScriptCodepointListPrivate));
+  _gucharmap_intl_ensure_initialized ();
+
+  g_type_class_add_private (codepoint_list_class, sizeof (GucharmapScriptCodepointListPrivate));
 
   codepoint_list_class->get_char = get_char;
   codepoint_list_class->get_index = get_index;
   codepoint_list_class->get_last_index = get_last_index;
   
-  gobject_class->finalize = finalize;
-
-  _gucharmap_intl_ensure_initialized ();
+  gobject_class->finalize = gucharmap_script_codepoint_list_finalize;
 }
 
 static void 
 gucharmap_script_codepoint_list_init (GucharmapScriptCodepointList *guscl)
 {
-  ScriptCodepointListPrivate *priv = GUCHARMAP_SCRIPT_CODEPOINT_LIST_GET_PRIVATE (guscl);
-  priv->ranges = NULL;
+  guscl->priv = G_TYPE_INSTANCE_GET_PRIVATE (guscl, GUCHARMAP_TYPE_SCRIPT_CODEPOINT_LIST, GucharmapScriptCodepointListPrivate);
 }
 
-G_DEFINE_TYPE (GucharmapScriptCodepointList, gucharmap_script_codepoint_list, gucharmap_codepoint_list_get_type ())
-
 /**
  * gucharmap_script_codepoint_list_new:
  *
@@ -319,11 +332,15 @@ gboolean
 gucharmap_script_codepoint_list_set_scripts (GucharmapScriptCodepointList  *list,
 	                                     const gchar                  **scripts)
 {
-  ScriptCodepointListPrivate *priv = GUCHARMAP_SCRIPT_CODEPOINT_LIST_GET_PRIVATE (list);
+  GucharmapScriptCodepointListPrivate *priv = list->priv;
   UnicodeRange *ranges;
   gint i, j, size;
-  
-  priv->ranges = g_ptr_array_new ();
+
+  if (priv->ranges)
+    clear_ranges (priv->ranges);
+  else
+    priv->ranges = g_ptr_array_new ();
+
   for (i = 0;  scripts[i];  i++)
     if (get_chars_for_script (scripts[i], &ranges, &size))
       {
@@ -354,7 +371,7 @@ gboolean
 gucharmap_script_codepoint_list_append_script (GucharmapScriptCodepointList  *list,
                                                const gchar                   *script)
 {
-  ScriptCodepointListPrivate *priv = GUCHARMAP_SCRIPT_CODEPOINT_LIST_GET_PRIVATE (list);
+  GucharmapScriptCodepointListPrivate *priv = list->priv;
   UnicodeRange *ranges;
   gint j, size, index0;
 
@@ -388,14 +405,28 @@ gucharmap_script_codepoint_list_append_script (GucharmapScriptCodepointList  *li
 /**
  * gucharmap_unicode_list_scripts:
  *
- * Return value: NULL-terminated array of script names. These have been
- * marked for translation with N_(). Neither the list nor the scripts
- * should be modified by the caller.
+ * Return value: %NULL-terminated array of script names. These have been
+ * marked for translation with N_().
+ * The strings in the array are owned by gucharmap and should not be
+ * modified or free; the array itself however is allocated and should
+ * be freed with g_free().
+ *
+ * Returns: a newly allocated %NULL-terminated array of strings
  **/
-G_CONST_RETURN gchar **
+const gchar **
 gucharmap_unicode_list_scripts (void)
 {
-  return unicode_script_list;
+  const char **scripts;
+  guint i;
+
+  scripts = (const char **) g_new (char*, G_N_ELEMENTS (unicode_script_list_offsets) + 1);
+  for (i = 0; i < G_N_ELEMENTS (unicode_script_list_offsets); ++i)
+    {
+      scripts[i] = unicode_script_list_strings + unicode_script_list_offsets[i];
+    }
+  scripts[i] = NULL;
+
+  return scripts;
 }
 
 /**
@@ -424,7 +455,7 @@ gucharmap_unicode_get_script_for_char (gunichar wc)
       else if (wc < unicode_scripts[mid].start)
         max = mid - 1;
       else
-        return unicode_script_list[unicode_scripts[mid].script_index];
+        return unicode_script_list_strings + unicode_script_list_offsets[unicode_scripts[mid].script_index];
     }
 
   /* Unicode assigns "Common" as the script name for any character not
