@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005 Jason Allen
+ * Copyright © 2005 Jason Allen
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -13,22 +13,28 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
  */
 
 #ifndef GUCHARMAP_SETTINGS_H
 #define GUCHARMAP_SETTINGS_H
 
 #include <glib.h>
-#include <gtk/gtkwindow.h>
-#include <gucharmap/gucharmap-chapters-model.h>
+#include <gtk/gtk.h>
+#include <gucharmap/gucharmap.h>
 
 G_BEGIN_DECLS
 
+typedef enum
+{
+  GUCHARMAP_CHAPTERS_SCRIPT = 0,
+  GUCHARMAP_CHAPTERS_BLOCK  = 1
+} GucharmapChaptersMode;
+
 void         gucharmap_settings_initialize           (void);
 void         gucharmap_settings_shutdown             (void);
-ChaptersMode gucharmap_settings_get_chapters_mode    (void);
-void         gucharmap_settings_set_chapters_mode    (ChaptersMode mode);
+GucharmapChaptersMode gucharmap_settings_get_chapters_mode    (void);
+void         gucharmap_settings_set_chapters_mode    (GucharmapChaptersMode mode);
 gchar *      gucharmap_settings_get_font             (void);
 void         gucharmap_settings_set_font             (gchar *font);
 gunichar     gucharmap_settings_get_last_char        (void);
